summaryrefslogtreecommitdiff
path: root/include/linux/thermal.h
diff options
context:
space:
mode:
authorDaniel Lezcano <daniel.lezcano@linexp.org>2022-07-22 23:00:04 +0300
committerDaniel Lezcano <daniel.lezcano@linaro.org>2022-07-28 18:29:56 +0300
commite5bfcd30f88fdb0ce830229e7ccdeddcb7a59b04 (patch)
treec47529d1c4d9d9a99d48e992fcf06ba893f5ceac /include/linux/thermal.h
parente5f2cda61d068e14af95ed8ee74c80e565af3f29 (diff)
downloadlinux-e5bfcd30f88fdb0ce830229e7ccdeddcb7a59b04.tar.xz
thermal/core: Rename 'trips' to 'num_trips'
In order to use thermal trips defined in the thermal structure, rename the 'trips' field to 'num_trips' to have the 'trips' field containing the thermal trip points. Cc: Alexandre Bailon <abailon@baylibre.com> Cc: Kevin Hilman <khilman@baylibre.com> Signed-off-by: Daniel Lezcano <daniel.lezcano@linexp.org> Link: https://lore.kernel.org/r/20220722200007.1839356-8-daniel.lezcano@linexp.org Signed-off-by: Daniel Lezcano <daniel.lezcano@linaro.org>
Diffstat (limited to 'include/linux/thermal.h')
-rw-r--r--include/linux/thermal.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/linux/thermal.h b/include/linux/thermal.h
index 7e66970f0464..ae579a70cc1a 100644
--- a/include/linux/thermal.h
+++ b/include/linux/thermal.h
@@ -123,7 +123,7 @@ struct thermal_cooling_device {
* @trip_hyst_attrs: attributes for trip points for sysfs: trip hysteresis
* @mode: current mode of this thermal zone
* @devdata: private pointer for device private data
* @trips: number of trip points the thermal zone supports
* @trips_disabled; bitmap for disabled trips
* @passive_delay_jiffies: number of jiffies to wait between polls when
* performing passive cooling.
@@ -163,7 +163,7 @@ struct thermal_zone_device {
struct thermal_attr *trip_hyst_attrs;
enum thermal_device_mode mode;
void *devdata;
- int trips;
+ int num_trips;
unsigned long trips_disabled; /* bitmap for disabled trips */
unsigned long passive_delay_jiffies;
unsigned long polling_delay_jiffies;
@@ -123,7 +123,7 @@ struct thermal_cooling_device {
* @mode: current mode of this thermal zone
* @devdata: private pointer for device private data
- * @trips: number of trip points the thermal zone supports
+ * @num_trips: number of trip points the thermal zone supports
* @trips_disabled; bitmap for disabled trips
* @passive_delay_jiffies: number of jiffies to wait between polls when